@@ -8,15 +8,20 @@ from path import Path as path
 import environ
 import os
 
+env = environ.Env(
+    # set casting, default value
+    MEMBERPRESS_API_KEY=(str, "set-me-please"),
+    MEMBERPRESS_API_BASE_URL=(str, "https://yourdomain.com"),
+)
+
 # path to this file.
-BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
-environ.Env.read_env(os.path.join(BASE_DIR, ".env"))
-
-
-APP_ROOT = path(__file__).abspath().dirname().dirname()  # /blah/blah/blah/.../stepwise_grades
-REPO_ROOT = APP_ROOT.dirname()  # /blah/blah/blah/.../memberpress-digital-learning-openedx
+HERE = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
+APP_ROOT = path(__file__).abspath().dirname().dirname()  # /blah/blah/blah/.../memberpress_client
+REPO_ROOT = APP_ROOT.dirname()  # /blah/blah/blah/.../django-memberpress-client
 TEMPLATES_DIR = APP_ROOT / "templates"
 
+environ.Env.read_env(os.path.join(REPO_ROOT, ".env"))
+
 
 def plugin_settings(settings):
     """
@@ -25,6 +30,9 @@ def plugin_settings(settings):
     see: https://stackoverflow.com/questions/56129708/how-to-force-redirect-uri-to-use-https-with-python-social-app
     """
 
+    settings.MEMBERPRESS_API_KEY = env("MEMBERPRESS_API_KEY")
+    settings.MEMBERPRESS_API_BASE_URL = env("MEMBERPRESS_API_BASE_URL")
+
     settings.MEMBERPRESS_API_KEY_NAME = "MEMBERPRESS-API-KEY"  # noqa: F841
     settings.MEMBERPRESS_CACHE_EXPIRATION = 300  # noqa: F841
     settings.MEMBERPRESS_SENSITIVE_KEYS = [  # noqa: F841
@@ -37,5 +45,5 @@ def plugin_settings(settings):
     ]
 
     settings.MAKO_TEMPLATE_DIRS_BASE.extend([TEMPLATES_DIR])
-    settings.INSTALLED_APPS.append("django_extensions")
     settings.INSTALLED_APPS.append("django-environ")
+    settings.INSTALLED_APPS.append("validators")
